@@ -15,23 +15,19 @@
 #' S <- patient$rtstruct[[1]] 
 #' 
 #' # creation of a binary object
-#' bin.brain <- bin.from.roi (vol = CT, struct = S, roi.sname = "bra")
+#' bin.brain <- bin.from.roi (vol = CT, struct = S, roi.sname = "bra", 
+#'                            verbose = FALSE)
 #' # Volume calculation
 #' get.volume.from.bin (bin.brain)
 
 #' @export
 #' @importFrom methods is
 get.volume.from.bin <- function (bin) {
-  if (!is (bin, "volume")) {
-    warning ("bin should be a volume class object.")
-    return (NULL)
-  }
-  
-  if ((bin$modality!="binary")) {
-    warning ("bin must be modality binary.")
-    return (NULL)
-  }
-  
+  if (!is (bin, "volume")) 
+    stop ("bin should be a volume class object.")
+  if ((bin$modality!="binary")) 
+    stop ("bin must be modality binary.")
+
   
   return (sum (bin$vol3D.data, na.rm = TRUE) * abs(prod (bin$dxyz))/1000)
 }
