@@ -21,15 +21,10 @@
 #' @export
 vol.median <- function (vol,  alias = "", description = NULL) {
     
-  if (!is (vol, "volume")) {
-    warning ("vol should be a volume class object.")
-    return (NULL)
-  }
+  if (is.null (vol)) return (NULL)
+  if (!is (vol, "volume")) stop ("vol should be a volume class object.")
+  if (is.null(vol$vol3D.data)) stop ("empty vol$vol3D.data.")
   
-  if(is.null(vol$vol3D.data)){
-    warning ("empty vol$vol3D.data.")
-    return (NULL)
-  }
   if (is.null(description)) description <-  paste (vol$object.alias, "median")
   Md <- vol.copy (vol, alias = alias, description = description)
   
